@@ -17,7 +17,23 @@
 /* define if the compiler has int64_t */
 #ifndef LOG4CPP_HAVE_INT64_T 
 #define LOG4CPP_HAVE_INT64_T
-#define int64_t __int64  
+typedef __int64 int64_t;
+
+/* define if the compiler has in_addr_t */
+#ifndef LOG4CPP_HAVE_IN_ADDR_T 
+#define LOG4CPP_HAVE_IN_ADDR_T
+
+#ifndef u_long 
+typedef unsigned long u_long;
+#endif
+
+/* u_long is the type of in_addr.s_addr */
+typedef u_long in_addr_t;
+
+/* u_short is the type of sockaddr_in.sin_port */
+// typedef u_short		in_port_t;
+
+#endif
 
 #if defined(_MSC_VER) && _MSC_VER < 1300
 #define LOG4CPP_MISSING_INT64_OSTREAM_OP   
@@ -46,7 +62,7 @@
 
 /* Version number of package */
 #ifndef LOG4CPP_VERSION
-#define LOG4CPP_VERSION  "0.3.3"
+#define LOG4CPP_VERSION  "1.0"
 #endif
 
 /* define if the compiler implements namespaces */
@@ -59,11 +75,25 @@
 #define LOG4CPP_HAVE_SSTREAM 1
 #endif
 
+#if defined(_MSC_VER)
+#    if _MSC_VER < 1300
+#       define LOG4CPP_HAS_WCHAR_T 0
+#    else
+#       define LOG4CPP_HAS_WCHAR_T 1
+#    endif
+#else
+#   define LOG4CPP_HAS_WCHAR_T 1
+#endif
+
 /* define if the C library has snprintf */
 #ifndef LOG4CPP_HAVE_SNPRINTF
 #define LOG4CPP_HAVE_SNPRINTF 1
 #endif
 
+#if defined(_MSC_VER) && _MSC_VER >= 1300
+#define LOG4CPP_HAVE_LOCALTIME_R 1
+#endif
+
 /* define to get around problems with ERROR in windows.h */
 #ifndef LOG4CPP_FIX_ERROR_COLLISION
 #define LOG4CPP_FIX_ERROR_COLLISION 1
@@ -105,10 +135,26 @@
 #define LOG4CPP_CSTRING_NOT_IN_STD
 #endif
 
+#ifndef LOG4CPP_CTIME_NOT_IN_STD
+#define LOG4CPP_CTIME_NOT_IN_STD
+#endif
+
+#ifndef LOG4CPP_CMATH_NOT_IN_STD
+#define LOG4CPP_CMATH_NOT_IN_STD
+#endif
+
 #endif
 
 /* define mode_t. Move to Portability.hh if more platforms need it */
+#if !defined(__BORLANDC__)
 typedef int mode_t;
+#endif
+
+#if defined(_MSC_VER) && _MSC_VER == 1310
+// warning C4275: interface non dll class 'std::runtime_error' utilise comme base 
+// d'une interface dll class 'log4cpp::ConfigureFailure'
+#pragma warning(disable: 4275)
+#endif
 
 /* _INCLUDE_LOG4CPP_CONFIG_WIN32_H */
 #endif
